@@ -29,7 +29,7 @@
 #'   temperature and precipitation (i.e. both have code >= A). Each measurement
 #'   column has a corresponding `_code` column which reflects the data quality
 #'   of that measurement (see the [ECCC calculations
-#'   document](http://climate.weather.gc.ca/doc/Canadian_Climate_Normals_1981_2010_Calculation_Information.pdf)
+#'   document](https://climate.weather.gc.ca/doc/Canadian_Climate_Normals_1981_2010_Calculation_Information.pdf)
 #'   for more details)
 #'
 #'   Climate normals are downloaded from the url stored in option
@@ -39,7 +39,9 @@
 #' @return tibble with nested normals and first/last frost data
 #'
 #' @examples
-#' \dontrun{
+#'
+#' \donttest{
+#'
 #' # Find the climate_id
 #' stations_search("Brandon A", normals_only = TRUE)
 #'
@@ -68,8 +70,8 @@
 #' nm <- unnest(n, normals)
 #' f <- unnest(n, frost)
 #' both <- dplyr::full_join(nm, f)
-#' }
 #'
+#' }
 #' @export
 
 normals_dl <- function(climate_ids, normals_years = "1981-2010",
@@ -156,12 +158,16 @@ normals_raw <- function(loc,
                                ")"))
 
   # Download file
-  httr::GET(loc) %>%
+  status %>%
     httr::content(as = "text", encoding = "latin1") %>%
+    # Get rid of degree symbols right away
+    stringr::str_remove_all("\\u00B0") %>%
     stringr::str_split(pattern = "\n") %>%
     unlist()
 }
 
+normals_raw <- memoise::memoise(normals_raw, ~memoise::timeout(24 * 60 * 60))
+
 
 normals_extract <- function(n, return = "data") {
   wmo <- find_line(n, cols = "meets WMO standards")
@@ -187,8 +193,8 @@ data_extract <- function(n, climate_id) {
   # Remove frost dates
   n <- frost_find(n, type = "remove")
 
-  # Read normals
-  n <- utils::read.csv(text = n, check.names = FALSE, stringsAsFactors = FALSE)
+  # Read normals (expect warnings due to header rows, etc.)
+  suppressWarnings(n <- readr::read_csv(n, col_types = readr::cols()))
 
   if(nrow(n) == 0) return(dplyr::tibble())
 
@@ -326,9 +332,9 @@ frost_extract <- function(f, climate_id) {
   if(length(frost_free) > 0) {
     if(length(frost_probs) == 0) last <- length(f) else last <- frost_probs - 1
 
-    f1 <- utils::read.csv(text = f[frost_free:last],
-                          check.names = FALSE, header = FALSE,
-                          col.names = c("variable", "value", "frost_code")) %>%
+    f1 <- readr::read_csv(f[frost_free:last],
+                          col_names = c("variable", "value", "frost_code"),
+                          col_types = readr::cols()) %>%
       tidyr::spread(key = "variable", value = "value")
 
     n <- tibble_to_list(f_names[f_names$variable %in% names(f1),
@@ -343,8 +349,9 @@ frost_extract <- function(f, climate_id) {
 
   # Frost free probabilities
   if(length(frost_probs) > 0) {
-    f2 <- utils::read.csv(text = f[frost_probs:length(f)],
-                          header = FALSE, stringsAsFactors = FALSE)
+    f2 <- readr::read_csv(f[frost_probs:length(f)],
+                          col_names = FALSE, col_types = readr::cols()) %>%
+      as.data.frame()
     f2 <- data.frame(prob = rep(c("10%", "25%", "33%", "50%",
                                   "66%", "75%", "90%"), 3),
                      value = c(t(f2[2, 2:8]), t(f2[4, 2:8]), t(f2[6, 2:8])),
